@@ -16,7 +16,8 @@ def feature_values_using_filter(
     feature_name : String
         The name of the column that the user wants to change values for.
     filter_ : Array
-        Indicates the rows with the index "id_" of the "feature_name" that must be changed.
+        Indicates the rows with the index "id_" of the "feature_name"
+        that must be changed.
     values : ?
         THe new values to be set to the selected feature.
     inplace: boolean, optional(True by default)
@@ -25,17 +26,18 @@ def feature_values_using_filter(
 
     Returns
     -------
-    move_data : dataframe
-        A copy of the original dataframe, with the alterations done by the function. (When inplace is False)
-    None
-        When inplace is True
+    dataframe or None
+        A copy of the original dataframe, with the alterations done
+        by the function. (When inplace is False)
 
     Notes
     -----
     equivalent to: move_data.at[id_, feature_name][filter_] = values
     e.g. move_data.at[tid, "time"][filter_nodes] = intp_result.astype(np.int64)
     dataframe must be indexed by id_: move_data.set_index(index_name, inplace=True)
+
     """
+
     if not inplace:
         move_data = PandasMoveDataFrame(data=move_data.to_DataFrame())
 
@@ -62,26 +64,28 @@ def feature_values_using_filter_and_indexes(
     ----------
     move_data : pandas.core.frame.DataFrame
         Represents the dataset with contains lat, long and datetime.
-
     id_ : String
         ?
-
     feature_name : String
         ?.
-
     filter_ : ?
         ?.
-
     idxs: ?
         ?.
-
     values : ?
         ?.
-
+    inplace: boolean, optional(True by default)
+        if set to true the original dataframe will be altered,
+        otherwise the alteration will be made in a copy, that will be returned.
 
     Returns
     -------
+    dataframe or None
+        A copy of the original dataframe, with the alterations
+        done by the function. (When inplace is False)
+
     """
+
     if not inplace:
         move_data = PandasMoveDataFrame(data=move_data.to_DataFrame())
 
